# encoding: utf-8

# Copyright (c) [2018] SUSE LLC
#
# All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of version 2 of the GNU General Public License as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may
# find current contact information at www.novell.com.

module Y2Sap
  # Copy content of media to target directory
  module MediaCopy
    include Yast
    Yast.import "Progress"

    def copy_dir(source_dir, target_dir, sub_dir)
      log.info("Y2Sap::MediaCopy.copy_dir called: #{source_dir}, #{target_dir}, #{sub_dir}")
      pid = start_copy(source_dir, target_dir, sub_dir)
      if pid.nil? || pid < 1
        return ask_me_to_retry(source_dir, target_dir, sub_dir)
      end
      source_size = human_size(source_dir)
      techsize = tech_size(source_dir)
      Progress.Simple(
        "Copying Media",
        "Copying SAP " + sub_dir + " ( 0M of " + source_size + " )",
        techsize,
        ""
      )
      Progress.NextStep
      show_progress(pid, source_dir, target_dir, sub_dir, source_size)
      # release the process from the agent
      SCR.Execute(path(".process.release"), pid)
      Progress.Finish
      return :next
    end

    def start_copy(source, target, subdir)
      log.info("CopyFiles called: #{source}, #{target}, #{subdir}")
      cmd = format("mkdir -p '%s/%s'", target, subdir)
      SCR.Execute(path(".target.bash"), cmd)

      # our copy command
      cmd = format("find '%s/'* -maxdepth 0 -exec cp -a '{}' '%s/%s/' \\;", source, target, subdir)
      pid = Convert.to_integer(SCR.Execute(path(".process.start_shell"), cmd))
      return pid
    end

    def tech_size(dir)
      cmd = format("du -s0 '%s' | awk '{printf $1}'", dir)
      out = SCR.Execute(path(".target.bash_output"), cmd)
      out["stdout"].to_i
    end

    def human_size(dir)
      cmd = format("du -sh0 '%s' | awk '{printf $1}'", dir)
      out = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      out["stdout"]
    end

    def ask_me_to_retry(source_dir, target_dir, sub_dir)
      if Popup.ErrorAnyQuestion(
        "Failed to copy files from medium",
        "Would you like to retry?",
        "Retry",
        "Abort",
        :focus_yes
      )
        copy_dir(source_dir, target_dir, sub_dir)
      else
        UI.CloseDialog
        return :abort
      end
    end

    def show_progress(pid, source_dir, target_dir, sub_dir, source_size)
      while SCR.Read(path(".process.running"), pid) == true
        sleep(2)
        techsize = tech_size(target_dir + "/" + sub_dir)
        Progress.Step(techsize)
        humansize = human_size(target_dir + "/" + sub_dir)
        Progress.Title("Copying Media " + sub_dir + " ( " + humansize + " of " + source_size + " )")

        # Checking the exit code (0 = OK, nil = still running, 'else' = error)
        exitcode = Convert.to_integer(SCR.Read(path(".process.status"), pid))
        stderr   = SCR.Read(path(".process.read_stderr"), pid)
        next if exitcode.nil? || exitcode == 0
        log.info("Copy has failed, exit code was: #{exitcode} stderr: " + stderr)
        Popup.Error(
          format("Copy has failed, exit code was: %i, stderr: %s", exitcode, stderr)
        )
        return ask_me_to_retry(source_dir, target_dir, sub_dir)
      end
    end
  end
end
